Struct InfraConfig

pub struct InfraConfig {
Show 40 fields pub port: u16, pub env: Environment, pub ws_config: WebsocketConfig, pub tg_bot_token: String, pub db_pool_config: Config, pub db_use_tls: bool, pub txn_max_retries: u16, pub db_request_referrals_limit: u16, pub db_request_abilities_limit: u16, pub hostname: String, pub web_hostname: Option<String>, pub db_sync_period: f64, pub state_updater_enabled: bool, pub game_tick_enabled: bool, pub cron_trigger_period: f64, pub webauthn_rp_id: String, pub webauthn_rp_origin: String, pub allowed_usernames: Vec<String>, pub otlp_http_export_endpoint: String, pub otlp_username: Option<String>, pub otlp_password: Option<String>, pub otlp_sampling_rate: f64, pub show_metrics_logs: bool, pub locale_folder_path: String, pub default_locale: String, pub analytics_gcs_logs_enabled: bool, pub analytics_gcs_bucket: Option<String>, pub analytics_gcs_folder: Option<String>, pub analytics_gcs_upload_interval_secs: u64, pub pyroscope_url: Option<String>, pub firebase_project_id: String, pub backend_version: Version, pub disconnect_log_events_count: usize, pub android_package_name: String, pub google_play_max_retries: u16, pub google_play_retry_base_ms: u64, pub moderation_config: ModerationConfig, pub admin_api_key: Option<String>, pub realms_service_url: Option<String>, pub realm_name: Option<String>,
}

Fields

port: u16env: Environmentws_config: WebsocketConfigtg_bot_token: Stringdb_pool_config: Configdb_use_tls: booltxn_max_retries: u16db_request_referrals_limit: u16db_request_abilities_limit: u16hostname: Stringweb_hostname: Option<String>db_sync_period: f64state_updater_enabled: boolgame_tick_enabled: boolcron_trigger_period: f64webauthn_rp_id: Stringwebauthn_rp_origin: Stringallowed_usernames: Vec<String>otlp_http_export_endpoint: Stringotlp_username: Option<String>otlp_password: Option<String>otlp_sampling_rate: f64show_metrics_logs: boollocale_folder_path: Stringdefault_locale: Stringanalytics_gcs_logs_enabled: boolanalytics_gcs_bucket: Option<String>analytics_gcs_folder: Option<String>analytics_gcs_upload_interval_secs: u64pyroscope_url: Option<String>firebase_project_id: Stringbackend_version: Versiondisconnect_log_events_count: usizeandroid_package_name: Stringgoogle_play_max_retries: u16google_play_retry_base_ms: u64moderation_config: ModerationConfigadmin_api_key: Option<String>

Shared admin secret. Used for two things:

  • POST /api/admin/* middleware (panel → monolith calls).
  • X-Admin-API-Key when calling realms-service /ack_realm. Ops provision the same value into the realms-service secret under admin_api_key so both services accept each other’s requests.
realms_service_url: Option<String>

Realms-service entry point (e.g. https://realms.overlord.lumex.team). Required on Prestable/Prod so the monolith can acknowledge that the connecting user was actually routed here by /pick_realm.

realm_name: Option<String>

Slug that this monolith deploy uses to identify itself to realms-service (matches realms.name in the realms-service DB, e.g. r0).

Implementations